@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # all names not starting with under score must be a subcommand module.
-import jsonstream as jsons
+import jss
 import tsv
 import io
 # import util
