@@ -5,6 +5,12 @@ import json
 import time
 import panya
 
+def ints(start=0):
+    n=start
+    while True:
+        yield n
+        n+=1
+
 @panya.command
 def read_lines(file=sys.stdin):
     """non-buffered, chomped readlines()"""
@@ -30,6 +36,24 @@ def read_tsv(file=sys.stdin):
     for line in read_lines(file):
         yield line.split('\t')
 
+@panya.command
+def repeat(n=None):
+    """repeat lines read from stdin 
+    up to n iterations or forever"""
+
+    max_iterations=int(n) if n else None
+
+    lines=[ line.strip() for line in read_lines(sys.stdin) ]
+
+    for i in ints():
+
+        if max_iterations and i>=max_iterations: 
+            break
+
+        for line in lines:
+            print line
+
+
 @panya.command
 def slowly(secs, imports=''):
     """echo lines slowly
