@@ -22,9 +22,11 @@ class Panya(object):
             import baker
         self.baker=baker
     
-    def register_command(self, f):
+    def register_command(self, f, func_name=None):
         """deocrate command function, like baker.command"""
-        self.funcs.append(CmdFunc(f, f.func_name, f.__module__, f.func_doc))
+        if not func_name:
+            func_name=f.func_name
+        self.funcs.append(CmdFunc(f, func_name, f.__module__, f.func_doc))
         return f
 
     def register(self):
